@@ -1,8 +1,6 @@
 import peewee
 from peewee import Model, EXCLUDED
 
-from airflow import AirflowException
-
 
 class BaseModel(Model):
     def bulk_save(self, rows: list, transaction_count=None):
@@ -10,23 +8,21 @@ class BaseModel(Model):
         update_fields = self.get_excluded_fields()
 
         # Delete duplicates
-        rows = list({''.join([str(x.get(field)) for field in conflict_fields]): x for x in rows}.values())
-
-        if not rows:
-            raise AirflowExecption("rows are empty")
+        rows = list({''.join([str(x.get(field)) for field in conflict_fields]): self.match_schema(x) for x in rows}.values())
 
         if not transaction_count:
             transaction_count = len(rows)
 
-        for index in range(0, len(rows), transaction_count):
-            if conflict_fields:
-                self.insert_many(rows[index:index + transaction_count]).on_conflict(
-                    action=None,
-                    conflict_target=conflict_fields,
-                    update=update_fields,
-                ).execute()
-            else:
-                self.insert_many(rows[index:index + transaction_count]).execute()
+        if transaction_count:
+            for index in range(0, len(rows), transaction_count):
+                if conflict_fields and update_fields:
+                    self.insert_many(rows[index:index + transaction_count]).on_conflict(
+                        action=None,
+                        conflict_target=conflict_fields,
+                        update=update_fields,
+                    ).execute()
+                else:
+                    self.insert_many(rows[index:index + transaction_count]).execute()
 
     def save_or_update(self, row):
         conflict_fields = self.get_model_indexes()
